# -*- coding: utf-8 -*-
"""
Created on Fri Nov 24 14:54:24 2023

@author: smvanessen
"""

# Clear all variables
from IPython import get_ipython
get_ipython().magic('reset -sf')

# Standard toolboxes
import numpy as np
import matplotlib.pyplot as plt
import os

# Allow for subsampling of large datasets for plotting & saving as PDF
from functions.subsample_routines import subsample_binned

# Close all figures
plt.close('all')


#############
# START INPUT
#############

# Weibull percentage
weiper = 50

# Folder with files to read (rel. to present folder).. These files are written 
# to this file by running Adaptive Screening with MF-GPR and sampling option B.
in_filefolder = 'out_files'

# Folder in which to store output figure (rel. to present folder).
out_figfolder = 'out_figs'

# Initial sample option (see Adaptive Screening script)
# init_samp_opt = 'A_LFsubsamp'
init_samp_opt = 'B_LFfit' # default
# init_samp_opt = 'C_LFisHFfit'

#############
# END INPUT
#############


# Check wether output directories exist, if not make them
isExist1 = os.path.exists(out_figfolder)
if not isExist1:
   os.makedirs(out_figfolder)

# Read data LF samples
DatLFtrue_Good = np.loadtxt(f'{in_filefolder}/Lin2nd_trueLFdata_GoodInd_{init_samp_opt}.csv', delimiter=',')
v_true_l_NN = DatLFtrue_Good[:,0]
p_true_l_NN = DatLFtrue_Good[:,1]
DatLFtrue_Medium = np.loadtxt(f'{in_filefolder}/Lin2nd_trueLFdata_MediumInd_{init_samp_opt}.csv', delimiter=',')
v_true_l_ST = DatLFtrue_Medium[:,0]
p_true_l_ST = DatLFtrue_Medium[:,1]
DatLFtrue_Bad = np.loadtxt(f'{in_filefolder}/Lin2nd_trueLFdata_BadInd_{init_samp_opt}.csv', delimiter=',')
v_true_l_LT = DatLFtrue_Bad[:,0]
p_true_l_LT = DatLFtrue_Bad[:,1]

# Subsample the MCS true distribution data for plotting later
binsize = 0.05
bins = np.arange(0,15,binsize)
v_true_l_NN_samp,p_true_l_NN_samp = subsample_binned(v_true_l_NN,p_true_l_NN,bins)
v_true_l_ST_samp,p_true_l_ST_samp = subsample_binned(v_true_l_ST,p_true_l_ST,bins)
v_true_l_LT_samp,p_true_l_LT_samp = subsample_binned(v_true_l_LT,p_true_l_LT,bins)

# Read Weibull fits to data 
Wei_NoNoise = np.genfromtxt(f'{in_filefolder}/GoodInd_LFsamples_3pWeibullfit_to_top{weiper}p.csv',skip_header=1,delimiter=',')
v_wei_NN = Wei_NoNoise[:,0]
p_wei_NN = Wei_NoNoise[:,1]
Wei_ShortTp = np.genfromtxt(f'{in_filefolder}/MediumInd_LFsamples_3pWeibullfit_to_top{weiper}p.csv',skip_header=1,delimiter=',')
v_wei_ST = Wei_ShortTp[:,0]
p_wei_ST = Wei_ShortTp[:,1]
Wei_LongTp = np.genfromtxt(f'{in_filefolder}/BadInd_LFsamples_3pWeibullfit_to_top{weiper}p.csv',skip_header=1,delimiter=',')
v_wei_LT = Wei_LongTp[:,0]
p_wei_LT = Wei_LongTp[:,1]

# Plot
plt.figure(figsize=(10,3))
plt.subplot(1,3,1)
plt.yscale('log')
plt.plot(v_true_l_NN_samp,p_true_l_NN_samp,'.',color='lightblue',label='GoodInd samples')
plt.plot(v_wei_NN,p_wei_NN,':',color='blue')
plt.title('GoodInd')
plt.ylabel('P(C\'$\geq$c) [-]')
plt.xlabel('c [m]')
plt.subplot(1,3,2)
plt.yscale('log')
plt.plot(v_true_l_ST_samp,p_true_l_ST_samp,'.',color='lightblue',label='MediumInd samples')
plt.plot(v_wei_ST,p_wei_ST,':',color='blue')
plt.title('MediumInd')
plt.xlabel('c [m]')
plt.subplot(1,3,3)
plt.yscale('log')
plt.plot(v_true_l_LT_samp,p_true_l_LT_samp,'.',color='lightblue',label='BadInd samples')
plt.plot(v_wei_LT,p_wei_LT,':',color='blue')
plt.title('BadInd')
plt.xlabel('c [m]')

plt.savefig(f'{out_figfolder}/Fig8_Weibull_fits_to_top{weiper}p_LF_samples.pdf',bbox_inches='tight')
