# -*- coding: utf-8 -*-
"""
Created on Thu Nov  3 11:58:45 2022
@author: smvanessen
"""

# Clear all variables
from IPython import get_ipython
get_ipython().magic('reset -sf')

# Standard toolboxes
import numpy as np
import matplotlib.pyplot as plt
import sys
import os

# Allow for subsampling of large datasets for plotting & saving as PDF
sys.path.append('functions')
from functions.subsample_routines import subsample_binned_2D

# Close all figures
plt.close('all')


#############
# START INPUT
#############

# Indicator case (comment the three others)
indcases = ['PerfInd','GoodInd','MediumInd','BadInd']

   
# Folder name where input files are stored (files to read)
inputfolder = 'waveinputfiles'
    
# Folder name in which to store files and figures (rel. to present folder)
figfolder = 'out_figs'

# Number of seeds (need to comply with available data)
Ns = 50 

#############
# END INPUT
#############

# Initialise
colgrey = [0.7,0.7,0.7]
# fig7 = plt.figure(7,figsize=(6,3.75))
fig7 = plt.figure(7,figsize=(4.8,3.75))
xticksnew = np.arange(0,16,5)
yticksnew = np.arange(0,16,5)

for nn,indcase in enumerate(indcases):

    # Check wether output directories exist, if not make them
    isExist = os.path.exists(figfolder)
    if not isExist:
       os.makedirs(figfolder)
    
    # Read true MCS time trace data from CSV
    AllTrueDat_scr = np.loadtxt(f'{inputfolder}/Lin2nd_trueLFandHFdata_{indcase}_{Ns}seeds_scr.csv', delimiter=',')
    t_peaks_lin_all = AllTrueDat_scr[:,0]
    peaks_lin_all = AllTrueDat_scr[:,1]
    t_peaks_2nd_all = AllTrueDat_scr[:,2]
    peaks_2nd_all = AllTrueDat_scr[:,3]
        
    # Subsample for the scatter plots
    xbinsize = 0.1
    ybinsize = 0.1
    xbins = np.arange(0,15,xbinsize)
    ybins = np.arange(0,15,ybinsize)
    peaks_lin_all_samp,peaks_2nd_all_samp = subsample_binned_2D(peaks_lin_all,peaks_2nd_all,xbins,ybins)
    
    # Scatter plot indicator vs NL response peaks and selected samples
    plt.subplot(2,2,nn+1)
    plt.plot(peaks_lin_all_samp,peaks_2nd_all_samp,marker='o',color=colgrey,label='All peaks',linestyle = 'None')
    plt.plot(np.array([0,15]),np.array([0,15]),'--',color='grey')
    if nn > 1:
        # plt.xlabel('LF indicator: linear wave crests [m]')
        plt.xticks(xticksnew)
    else:
        plt.xticks(xticksnew,labels=[])
    if nn == 0 or nn == 2:
        # plt.ylabel('HF response: 2$^{nd}$-\n order wave crests [m]')
        plt.yticks(yticksnew)
    else:
        plt.yticks(yticksnew,labels=[])
    plt.xlim([0,15])
    plt.ylim([0,15])
    plt.title(f'{indcase}')
    

# Add shared axes labels and save figure
fig7.text(0.5, 0.02, 'LF indicator: linear wave crests [m]', ha='center')
fig7.text(0.03, 0.5, 'HF response: 2$^{nd}$-order wave crests [m]', va='center', rotation='vertical')
plt.savefig(f'{figfolder}/Fig6_Scatters.pdf',bbox_inches='tight')

