# -*- coding: utf-8 -*-
"""
Created on Fri Aug  4 13:29:15 2023

@author: smvanessen
"""

from typing import Tuple, Union

import numpy as np

from emukit.core.acquisition import Acquisition
from emukit.core.interfaces import IModel, IDifferentiable

class MaxV(Acquisition):
    """
    This acquisition selects the point in the domain where the predicted mean value is the highest
    """
    def __init__(self, model: Union[IModel, IDifferentiable]) -> None:
        self.model = model

    def evaluate(self, x: np.ndarray) -> np.ndarray:
        mean, _ = self.model.predict(x)
        return mean

    def evaluate_with_gradients(self, x: np.ndarray) -> Tuple:
        mean,_ = self.model.predict(x)
        dmean_dx,_ = self.model.get_prediction_gradients(x)
        return mean, dmean_dx

    def has_gradients(self):
        return isinstance(self.model, IDifferentiable)
