
import numpy as np


class ParabPdist:
    """
    This acquisition function selects points with the smallest absolute 
	difference in probability level from Prange with the target level Ptarget.
    """
    
    def __init__(self,Ptarget: float) -> None:
        self.Ptarget = Ptarget

    def evaluate(self,Prange: np.ndarray) -> np.ndarray:
                
        # # Alternative - normalised and then inverted distance
        # dist = np.abs(Prange-self.Ptarget)
        # distnorminv = 1-(dist / np.max(dist))
        
        # Define 'mountain parabola'
        parabola = 1-(Prange-self.Ptarget)**2
        
        # Normalise to values between 0 and 1
        t1 = parabola-(np.min(parabola))
        distparab = t1/np.max(t1)
        
        return distparab
    
    @property
    def has_gradients(self):
        return False

