# -*- coding: utf-8 -*-
"""
Created on Wed Sep  6 16:47:18 2023

@author: smvanessen
"""

# Clear all variables
from IPython import get_ipython
get_ipython().magic('reset -sf')

# Standard toolboxes
import numpy as np
import matplotlib.pyplot as plt
import sys

# Import adaptive screening function
from Adaptive_Screening_v1 import adaptive_screening

# Import some other custom functions used to analyse the true validation data and plot results
sys.path.append('functions')
from functions.distribution_scripts import calc_distribution

# Close all figures
plt.close('all')


#############
# START INPUT
#############

# Selected acquisition function and number of considered iterations for GPR
acqHF = 'USMV'
maxitHF = 6

# Selected acquisition function and number of considered iterations for MF-GPR
acqMF = 'USMV'
maxitMF = 6

# Folder name where input files are stored (files to read)
inputfolder = 'waveinputfiles'

# Output folder name in which to store files and figures (rel. to present folder)
filefolder = 'out_files'
figfolder = 'out_figs'

# Target exposure duration [s]
dur = 3600

# Number of seeds. Should comply with the available data, in this case 
# generated using 'Generate_Lin_2nd_MCS_data.py'.
Ns = 50

# Peak primary wave period for all cases
Tp = 11

# Initial sample option (see Adaptive Screening script)
init_sampopt = 'B'

# Probabilty of exceedance (PoE) range for the prediction
prange_low = 5*10**(-4)
prange_high = 2*10**(-2)
prange_nostep = 201
prange = np.linspace(prange_low,prange_high,prange_nostep)[:, None]

# Probability of exceedance (PoE) levels of two initial samples
init_plevels = np.array([0.001,0.01])


#############
# END INPUT
#############

# Loop over all four indicator quality cases
for nn in range(4):

    # Input noise (indicator quality) case. Comment the three other options.
    if nn == 0:
        indcase = 'PerfInd'
    elif nn == 1:
        indcase = 'GoodInd'
    elif nn == 2:
        indcase = 'MediumInd'
    elif nn == 3:
        indcase = 'BadInd'   
      
    # Derive target exposure duration probability level
    ne_exp = dur/Tp
     
    # Read MCS linear and 2nd order true wave time traces from CSV file
    AllTrueDat_scr = np.loadtxt(f'{inputfolder}/Lin2nd_trueLFandHFdata_{indcase}_{Ns}seeds_scr.csv', delimiter=',')
    peaks_lin_all = AllTrueDat_scr[:,1]
    peaks_2nd_all_scr = AllTrueDat_scr[:,3]
    AllTrueDat_true = np.loadtxt(f'{inputfolder}/Lin2nd_trueLFandHFdata_{indcase}_{Ns}seeds_true2nd.csv', delimiter=',')
    peaks_2nd_all_true = AllTrueDat_true[:,1]
         
    # Calculate true distributions for 'Monte-Carlo' dataset (all data, validation)
    v_2nd_all_true,p_2nd_all_true = calc_distribution(peaks_2nd_all_true)
          
    # Run Adaptive Screening
    adaptive_screening(peaks_lin_all,peaks_2nd_all_scr,peaks_2nd_all_true,acqHF,acqMF,maxitHF,maxitMF,prange,init_sampopt,init_plevels,dur,ne_exp,filefolder,figfolder,indcase)
    
    # Close all figures
    plt.close('all')